==> pyprocessors_gallery-0.1.0.dev0-py3-none-any.whl: pyprocessors_gallery/gallery.py <==
from enum import Enum
from typing import Type, List, cast, Dict, Optional
from pydantic import BaseModel, Field
from pymultirole_plugins.v1.processor import ProcessorParameters, ProcessorBase
from pymultirole_plugins.v1.schema import Document


class GalleryEnum(str, Enum):
    A = 'A'
    B = 'B'
    C = 'C'


class GalleryOptions(BaseModel):
    foo: str = Field("foo", description="String value")
    bar: float = Field(1.2345, description="Float value")


class GalleryParameters(ProcessorParameters):
    options_val: GalleryOptions = Field(None, description="Options value")
    str_value: str = Field("string", description="String value")
    float_value: float = Field(1.2345, description="Float value")
    int_value: int = Field(1, description="Integer value")
    bool_value: bool = Field(True, description="Boolean value")
    advanced: str = Field(None,
                          description="Advanced parameter (Hidden by default)",
                          extra="advanced")
    internal: str = Field(None,
                          description="Internal parameter (Always hidden)",
                          extra="internal")
    one_json: Optional[str] = Field(None, description="One json object", extra="json")
    one_jsonarray: Optional[List[str]] = Field(None,
                                               description="""Json array with a very long description with markdown, then you need to define a single rule composed of 2 tokens:<ol>
        <li>A token whose `IS_SPACE` flag is set to true and that contains at least one line break `\\n`
        <li>A token whose `TEXT` is in a list of predefined paragraph triggers `["Chapter", "Title"]`
        </ol>
        Keys starting with `__comment` are considered as comments.<br/>
        Then you need to define a rule like:<br/>
    ```
    [
        [
            {
                "__comment": "Split on line break...",
                "IS_SPACE": True,
                "TEXT": {
                    "REGEX": "(.?\\n){1,}"
                }
            },
            {
                "__comment1": "... only if followed by paragraph trigger word",
                "LOWER": {
                    "IN": [
                        "chapter", "title"
                    ]
                },
                "__comment2": "... starting by an uppercase letter",
                "SHAPE": {
                    "REGEX": "^X"
                }
            }
        ]
    ]
    ```""", extra="jsonarray")
    one_label: Optional[str] = Field(None, description="One label", extra="label")
    label2json_mapping: Dict[str, str] = Field(None, description="Label to json mapping", extra="key:label,val:json")
    one_lang: Optional[str] = Field(None, description="One language", extra="language")
    lang2json_mapping: Dict[str, str] = Field(None, description="Language to json mapping",
                                              extra="key:language,val:json")
    many_labels: List[str] = Field(None, description="List of labels", extra="label")
    one_lexicon: str = Field(None, description="One lexicon", extra="lexicon")
    one_enum: GalleryEnum = Field(GalleryEnum.A,
                                  description="One enum with default value")
    lexicon2enum_mapping: Dict[str, GalleryEnum] = Field(None,
                                                         description="Lexicon to component enum",
                                                         extra="key:lexicon")


class GalleryProcessor(ProcessorBase):
    """Gallery processor .
    #languages:en,fr,de
    #needs-segments
    """

    def process(self, documents: List[Document], parameters: ProcessorParameters) \
            -> List[Document]:
        params: GalleryParameters = \
            cast(GalleryParameters, parameters)
        return documents

    @classmethod
    def get_model(cls) -> Type[BaseModel]:
        return GalleryParameters

==> pyprocessors_gallery-0.1.1-py3-none-any.whl: pyprocessors_gallery/gallery.py <==
from enum import Enum
from typing import Type, List, cast, Dict, Optional
from pydantic import BaseModel, Field
from pymultirole_plugins.v1.processor import ProcessorParameters, ProcessorBase
from pymultirole_plugins.v1.schema import Document


class GalleryEnum(str, Enum):
    A = 'A'
    B = 'B'
    C = 'C'


class GalleryOptions(BaseModel):
    foo: str = Field("foo", description="String value")
    bar: float = Field(1.2345, description="Float value")


class GalleryParameters(ProcessorParameters):
    options_val: GalleryOptions = Field(None, description="Options value")
    str_value: str = Field("string", description="String value")
    float_value: float = Field(1.2345, description="Float value")
    int_value: int = Field(1, description="Integer value")
    bool_value: bool = Field(True, description="Boolean value")
    advanced: str = Field(None,
                          description="Advanced parameter (Hidden by default)",
                          extra="advanced")
    internal: str = Field(None,
                          description="Internal parameter (Always hidden)",
                          extra="internal")
    one_json: Optional[str] = Field(None, description="""Json array with a very long description with markdown, then you need to define a single rule composed of 2 tokens:<ol>
        <li>A token whose `IS_SPACE` flag is set to true and that contains at least one line break `\\n`
        <li>A token whose `TEXT` is in a list of predefined paragraph triggers `["Chapter", "Title"]`
        </ol>
        Keys starting with `__comment` are considered as comments.<br/>
        Then you need to define a rule like:<br/>
    ```
    [
        [
            {
                "__comment": "Split on line break...",
                "IS_SPACE": True,
                "TEXT": {
                    "REGEX": "(.?\\n){1,}"
                }
            },
            {
                "__comment1": "... only if followed by paragraph trigger word",
                "LOWER": {
                    "IN": [
                        "chapter", "title"
                    ]
                },
                "__comment2": "... starting by an uppercase letter",
                "SHAPE": {
                    "REGEX": "^X"
                }
            }
        ]
    ]
    ```""", extra="json")
    one_label: Optional[str] = Field(None, description="One label", extra="label")
    label2json_mapping: Dict[str, str] = Field(None, description="Label to json mapping", extra="key:label,val:json")
    one_lang: Optional[str] = Field(None, description="One language", extra="language")
    lang2json_mapping: Dict[str, str] = Field(None, description="Language to json mapping",
                                              extra="key:language,val:json")
    many_labels: List[str] = Field(None, description="List of labels", extra="label")
    one_lexicon: str = Field(None, description="One lexicon", extra="lexicon")
    one_enum: GalleryEnum = Field(GalleryEnum.A,
                                  description="One enum with default value")
    lexicon2enum_mapping: Dict[str, GalleryEnum] = Field(None,
                                                         description="Lexicon to component enum",
                                                         extra="key:lexicon")


class GalleryProcessor(ProcessorBase):
    """Gallery processor .
    #languages:en,fr,de
    #needs-segments
    """

    def process(self, documents: List[Document], parameters: ProcessorParameters) \
            -> List[Document]:
        params: GalleryParameters = \
            cast(GalleryParameters, parameters)
        return documents

    @classmethod
    def get_model(cls) -> Type[BaseModel]:
        return GalleryParameters
